pub struct ChannelOneOf2 {
    pub channel_type: ChannelType,
    pub _id: String,
    pub name: String,
    pub owner: String,
    pub description: Option<String>,
    pub recipients: Vec<String, Global>,
    pub icon: Option<Box<File, Global>>,
    pub last_message_id: Option<String>,
    pub permissions: Option<i64>,
    pub nsfw: Option<bool>,
}
ChannelOneOf2 : Group channel between 1 or more participants

Fields

channel_type: ChannelType_id: String

Unique Id

name: String

Display name of the channel

owner: String

User id of the owner of the group

description: Option<String>

Channel description

recipients: Vec<String, Global>

Array of user ids participating in channel

icon: Option<Box<File, Global>>

Custom icon attachment

last_message_id: Option<String>

Id of the last message sent in this channel

permissions: Option<i64>

Permissions assigned to members of this group (does not apply to the owner of the group)

nsfw: Option<bool>

Whether this group is marked as not safe for work

Implementations

Group channel between 1 or more participants