Struct revolute::models::ChannelOneOf3
source · [−]pub struct ChannelOneOf3 {
pub channel_type: ChannelType,
pub _id: String,
pub server: String,
pub name: String,
pub description: Option<String>,
pub icon: Option<Box<File, Global>>,
pub last_message_id: Option<String>,
pub default_permissions: Option<Box<OverrideField, Global>>,
pub role_permissions: Option<HashMap<String, OverrideField, RandomState>>,
pub nsfw: Option<bool>,
}Expand description
ChannelOneOf3 : Text channel belonging to a server
Fields
channel_type: ChannelType_id: StringUnique Id
server: StringId of the server this channel belongs to
name: StringDisplay name of the channel
description: Option<String>Channel description
icon: Option<Box<File, Global>>Custom icon attachment
last_message_id: Option<String>Id of the last message sent in this channel
default_permissions: Option<Box<OverrideField, Global>>Default permissions assigned to users in this channel
role_permissions: Option<HashMap<String, OverrideField, RandomState>>Permissions assigned based on role to this channel
nsfw: Option<bool>Whether this channel is marked as not safe for work
Implementations
sourceimpl ChannelOneOf3
impl ChannelOneOf3
sourcepub fn new(
channel_type: ChannelType,
_id: String,
server: String,
name: String
) -> ChannelOneOf3
pub fn new(
channel_type: ChannelType,
_id: String,
server: String,
name: String
) -> ChannelOneOf3
Text channel belonging to a server