Struct revolute::models::DataEditBot
source · [−]pub struct DataEditBot {
pub name: Option<String>,
pub public: Option<bool>,
pub analytics: Option<bool>,
pub interactions_url: Option<String>,
pub remove: Option<Vec<FieldsBot, Global>>,
}Fields
name: Option<String>Bot username
public: Option<bool>Whether the bot can be added by anyone
analytics: Option<bool>Whether analytics should be gathered for this bot Must be enabled in order to show up on Revolt Discover.
interactions_url: Option<String>Interactions URL
remove: Option<Vec<FieldsBot, Global>>Fields to remove from bot object
Implementations
sourceimpl DataEditBot
impl DataEditBot
pub fn new() -> DataEditBot