Struct revolute::models::DataEditUserProfile
source · [−]Expand description
DataEditUserProfile : New user profile data This is applied as a partial.
Fields
content: Option<String>Text to set as user profile description
background: Option<String>Attachment Id for background
Implementations
sourceimpl DataEditUserProfile
impl DataEditUserProfile
sourcepub fn new() -> DataEditUserProfile
pub fn new() -> DataEditUserProfile
New user profile data This is applied as a partial.