Struct revolute::models::DataMessageSend
source · [−]pub struct DataMessageSend {
pub nonce: Option<String>,
pub content: Option<String>,
pub attachments: Option<Vec<String, Global>>,
pub replies: Option<Vec<Reply, Global>>,
pub embeds: Option<Vec<SendableEmbed, Global>>,
pub masquerade: Option<Box<DataMessageSendMasquerade, Global>>,
pub interactions: Option<Box<DataMessageSendInteractions, Global>>,
}Fields
nonce: Option<String>Unique token to prevent duplicate message sending This is deprecated and replaced by Idempotency-Key!
content: Option<String>Message content to send
attachments: Option<Vec<String, Global>>Attachments to include in message
replies: Option<Vec<Reply, Global>>Messages to reply to
embeds: Option<Vec<SendableEmbed, Global>>Embeds to include in message Text embed content contributes to the content length cap
masquerade: Option<Box<DataMessageSendMasquerade, Global>>interactions: Option<Box<DataMessageSendInteractions, Global>>Implementations
sourceimpl DataMessageSend
impl DataMessageSend
pub fn new() -> DataMessageSend