Struct revolute::models::ServerSystemMessages
source · [−]pub struct ServerSystemMessages {
pub user_joined: Option<String>,
pub user_left: Option<String>,
pub user_kicked: Option<String>,
pub user_banned: Option<String>,
}Expand description
ServerSystemMessages : Configuration for sending system event messages
Fields
user_joined: Option<String>ID of channel to send user join messages in
user_left: Option<String>ID of channel to send user left messages in
user_kicked: Option<String>ID of channel to send user kicked messages in
user_banned: Option<String>ID of channel to send user banned messages in
Implementations
sourceimpl ServerSystemMessages
impl ServerSystemMessages
sourcepub fn new() -> ServerSystemMessages
pub fn new() -> ServerSystemMessages
Configuration for sending system event messages