Struct revolute::models::channel_one_of_2::ChannelOneOf2
source · [−]pub struct ChannelOneOf2 {
pub channel_type: ChannelType,
pub _id: String,
pub name: String,
pub owner: String,
pub description: Option<String>,
pub recipients: Vec<String, Global>,
pub icon: Option<Box<File, Global>>,
pub last_message_id: Option<String>,
pub permissions: Option<i64>,
pub nsfw: Option<bool>,
}Expand description
ChannelOneOf2 : Group channel between 1 or more participants
Fields
channel_type: ChannelType_id: StringUnique Id
name: StringDisplay name of the channel
owner: StringUser id of the owner of the group
description: Option<String>Channel description
recipients: Vec<String, Global>Array of user ids participating in channel
icon: Option<Box<File, Global>>Custom icon attachment
last_message_id: Option<String>Id of the last message sent in this channel
permissions: Option<i64>Permissions assigned to members of this group (does not apply to the owner of the group)
nsfw: Option<bool>Whether this group is marked as not safe for work
Implementations
sourceimpl ChannelOneOf2
impl ChannelOneOf2
sourcepub fn new(
channel_type: ChannelType,
_id: String,
name: String,
owner: String,
recipients: Vec<String, Global>
) -> ChannelOneOf2
pub fn new(
channel_type: ChannelType,
_id: String,
name: String,
owner: String,
recipients: Vec<String, Global>
) -> ChannelOneOf2
Group channel between 1 or more participants